==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/AuthenticationFlowsPolicy.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.complex.SelfServiceSignUpAuthenticationFlowConfiguration;

@JsonPropertyOrder({
    "@odata.type", 
    "selfServiceSignUp", 
    "displayName", 
    "description"})
@JsonInclude(Include.NON_NULL)
public class AuthenticationFlowsPolicy extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.authenticationFlowsPolicy";
    }

    @JsonProperty("selfServiceSignUp")
    protected SelfServiceSignUpAuthenticationFlowConfiguration selfServiceSignUp;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("description")
    protected String description;

    protected AuthenticationFlowsPolicy() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAuthenticationFlowsPolicy() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private SelfServiceSignUpAuthenticationFlowConfiguration selfServiceSignUp;
        private String displayName;
        private String description;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder selfServiceSignUp(SelfServiceSignUpAuthenticationFlowConfiguration selfServiceSignUp) {
            this.selfServiceSignUp = selfServiceSignUp;
            this.changedFields = changedFields.add("selfServiceSignUp");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder description(String description) {
            this.description = description;
            this.changedFields = changedFields.add("description");
            return this;
        }

        public AuthenticationFlowsPolicy build() {
            AuthenticationFlowsPolicy _x = new AuthenticationFlowsPolicy();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.authenticationFlowsPolicy";
            _x.id = id;
            _x.selfServiceSignUp = selfServiceSignUp;
            _x.displayName = displayName;
            _x.description = description;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="selfServiceSignUp")
    @JsonIgnore
    public Optional<SelfServiceSignUpAuthenticationFlowConfiguration> getSelfServiceSignUp() {
        return Optional.ofNullable(selfServiceSignUp);
    }

    public AuthenticationFlowsPolicy withSelfServiceSignUp(SelfServiceSignUpAuthenticationFlowConfiguration selfServiceSignUp) {
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = changedFields.add("selfServiceSignUp");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.authenticationFlowsPolicy");
        _x.selfServiceSignUp = selfServiceSignUp;
        return _x;
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public AuthenticationFlowsPolicy withDisplayName(String displayName) {
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = changedFields.add("displayName");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.authenticationFlowsPolicy");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="description")
    @JsonIgnore
    public Optional<String> getDescription() {
        return Optional.ofNullable(description);
    }

    public AuthenticationFlowsPolicy withDescription(String description) {
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = changedFields.add("description");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.authenticationFlowsPolicy");
        _x.description = description;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AuthenticationFlowsPolicy patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AuthenticationFlowsPolicy put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private AuthenticationFlowsPolicy _copy() {
        AuthenticationFlowsPolicy _x = new AuthenticationFlowsPolicy();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.selfServiceSignUp = selfServiceSignUp;
        _x.displayName = displayName;
        _x.description = description;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AuthenticationFlowsPolicy[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("selfServiceSignUp=");
        b.append(this.selfServiceSignUp);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("description=");
        b.append(this.description);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/AuthenticationFlowsPolicy.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.complex.SelfServiceSignUpAuthenticationFlowConfiguration;

@JsonPropertyOrder({
    "@odata.type", 
    "description", 
    "displayName", 
    "selfServiceSignUp"})
@JsonInclude(Include.NON_NULL)
public class AuthenticationFlowsPolicy extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.authenticationFlowsPolicy";
    }

    @JsonProperty("description")
    protected String description;

    @JsonProperty("displayName")
    protected String displayName;

    @JsonProperty("selfServiceSignUp")
    protected SelfServiceSignUpAuthenticationFlowConfiguration selfServiceSignUp;

    protected AuthenticationFlowsPolicy() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderAuthenticationFlowsPolicy() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private String description;
        private String displayName;
        private SelfServiceSignUpAuthenticationFlowConfiguration selfServiceSignUp;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder description(String description) {
            this.description = description;
            this.changedFields = changedFields.add("description");
            return this;
        }

        public Builder displayName(String displayName) {
            this.displayName = displayName;
            this.changedFields = changedFields.add("displayName");
            return this;
        }

        public Builder selfServiceSignUp(SelfServiceSignUpAuthenticationFlowConfiguration selfServiceSignUp) {
            this.selfServiceSignUp = selfServiceSignUp;
            this.changedFields = changedFields.add("selfServiceSignUp");
            return this;
        }

        public AuthenticationFlowsPolicy build() {
            AuthenticationFlowsPolicy _x = new AuthenticationFlowsPolicy();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.authenticationFlowsPolicy";
            _x.id = id;
            _x.description = description;
            _x.displayName = displayName;
            _x.selfServiceSignUp = selfServiceSignUp;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="description")
    @JsonIgnore
    public Optional<String> getDescription() {
        return Optional.ofNullable(description);
    }

    public AuthenticationFlowsPolicy withDescription(String description) {
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = changedFields.add("description");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.authenticationFlowsPolicy");
        _x.description = description;
        return _x;
    }

    @Property(name="displayName")
    @JsonIgnore
    public Optional<String> getDisplayName() {
        return Optional.ofNullable(displayName);
    }

    public AuthenticationFlowsPolicy withDisplayName(String displayName) {
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = changedFields.add("displayName");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.authenticationFlowsPolicy");
        _x.displayName = displayName;
        return _x;
    }

    @Property(name="selfServiceSignUp")
    @JsonIgnore
    public Optional<SelfServiceSignUpAuthenticationFlowConfiguration> getSelfServiceSignUp() {
        return Optional.ofNullable(selfServiceSignUp);
    }

    public AuthenticationFlowsPolicy withSelfServiceSignUp(SelfServiceSignUpAuthenticationFlowConfiguration selfServiceSignUp) {
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = changedFields.add("selfServiceSignUp");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.authenticationFlowsPolicy");
        _x.selfServiceSignUp = selfServiceSignUp;
        return _x;
    }

    public AuthenticationFlowsPolicy withUnmappedField(String name, Object value) {
        AuthenticationFlowsPolicy _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AuthenticationFlowsPolicy patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public AuthenticationFlowsPolicy put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        AuthenticationFlowsPolicy _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private AuthenticationFlowsPolicy _copy() {
        AuthenticationFlowsPolicy _x = new AuthenticationFlowsPolicy();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.description = description;
        _x.displayName = displayName;
        _x.selfServiceSignUp = selfServiceSignUp;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("AuthenticationFlowsPolicy[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("description=");
        b.append(this.description);
        b.append(", ");
        b.append("displayName=");
        b.append(this.displayName);
        b.append(", ");
        b.append("selfServiceSignUp=");
        b.append(this.selfServiceSignUp);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
